# Creating an ORM adapter

To use SecondStep with a orm other then ActiveRecord, you'll need to create an
orm.

The orm should have a class for each model, implementing attributes and
relations for each model. All models are stored in </lib/second_step/models> as
an ActiveSupport::Concern. When creating a class to wrap the model, you should
include the concern. There is a comment on each model listing what an orm
implementation must provide. You can look at the memory and active_record
adapters to see an example of how to implement a model.

```ruby
# ORM implementation:
#
# Attributes: token
# Belongs to: application_user
```

Once you finish that, package your adapter in a module. If chosen as the orm to
use, it will be included into `SecondStep`. Make sure not to override any
SecondStep classes.

Now, register your adapter with SecondStep. This must be done before SecondStep
is configured.

```ruby
SecondStep.register_orm_adapter your_adapter_name: 'Name::Of::AdapterModule'
```

A user can chose to use your adapter by changing this line in their config to:
```ruby
orm_adapter :your_adapter_name
```
