# Getting Started

Thanks for choosing to use SecondStep. We'll get you started in just a few steps.

## Rails

SecondStep provides a Rails generator to make getting started a breeze.
First, run the generator. This will create the initializer and, if using
ActiveRecord, the migration.

```bash
$ rails generate second_step:install # Defaults to active_record
$ rails generate second_step:install --orm=memory # Store data in memory
$ rails generate second_step:install --orm=none # Don't do any specific orm configuration
```

After running the generator, you'll need an RSA private key. If you don't
already have one, you'll need to create it. You can use openssl to do this. Put
the passphrase in an environmental variable (we recommend the fabulous [dotenv]
gem for this). You should keep the private key and passphrase hidden from
version control. You should use a separate key for production and development.

```bash
$ openssl genrsa -des3 -out private.pem 2048
```

Next, get your api credentials from [SecondStep] and configure the gem using the
initializer.

If you're using ActiveRecord and you'd like to link your user model with the
corresponding SecondStep::ApplicationUser, you can automatically generate the
relationship like so:

```bash
$ rails g second_step:user_relationship # Defaults to User
$ rails g second_step:user_relationship Admin
```

Once you finish configuring the gem, link your public key with SecondStep. Run
the following command:

```bash
$ rake second_step:link_key
```

## Other

To use SecondStep without Rails, you'll need to create the files manually.

First, you'll need an RSA private key. If you don't
already have one, you'll need to create it. You can use openssl to do this. Put
the passphrase in an environmental variable (we recommend the fabulous [dotenv]
gem for this). You should keep the private key and passphrase hidden from
version control. You should use a separate key for production and development.

Next, get your api credentials from [SecondStep] and configure the gem. Here is
an [example configuration file][configuration].

If you are using ActiveRecord, you'll need to add the [migration][migration]. If
you would like to link your user model with the corresponding
SecondStep::ApplicationUser, you can specify the relationship by adding this
line to your model:

```ruby
has_one :second_step_application_user, class_name: 'SecondStep::ApplicationUser', foreign_key: :user_id
```

Now that you've finished configuring the gem, you'll need to add SecondStep's
[rake] tasks. Prepend this line to your `Rakefile`:

```ruby
require 'second_step/tasks'
```

Once you finish configuring the gem, you'll need to link your public key with
SecondStep if you created a new one. Run the following command:

```bash
$ rake second_step:link_key
```

Congrats! You've installed SecondStep. You can move onto [usage].

[configuration]: /lib/generators/second_step/install/templates/initializer.rb.erb
[migration]: /lib/generators/second_step/migration/templates/migration.rb
[SecondStep]: https://secondstep.bensites.com
[dotenv]: https://github.com/bkeepers/dotenv/
[rake]: https://github.com/ruby/rake
[usage]: /docs/usage.md
